@@ -1,3 +1,5 @@
+{-# LANGUAGE CPP #-}
+
 {-|
 This module makes the operations exported by @System.Posix.Time@
 available on all platforms. On POSIX systems it re-exports operations from
@@ -5,10 +7,10 @@ available on all platforms. On POSIX systems it re-exports operations from
 as possible.
 -}
 module System.PosixCompat.Time (
-    epochTime,
-  ) where
+      epochTime
+    ) where
 
-#ifdef UNIX_IMPL
+#ifndef mingw32_HOST_OS
 
 import System.Posix.Time
 
